# vs-jet

### PyPi package for quickly upgrading and installing all JET Python packages.

This package does not install any Vapoursynth plugins.<br>
For support inquiries, please join the [JET Discord server][discord]
or leave an [issue][issues].

## How to install

Install `vsjet` with the following command:

```sh
pip install vsjet
```

## How to use

Install the stable versions of all JET packages:

```sh
python -m vsjet
```

Upgrade to latest git version of all JET packages:

```sh
python -m vsjet latest
```

**Disclaimer:** Latest git packages may be unstable!
Please report issues in their [respective repositories][jet-repo].

[discord]: https://discord.gg/XTpc6Fa9eB
[issues]: https://github.com/Jaded-Encoding-Thaumaturgy/vs-jet/issues
[jet-repo]: https://github.com/orgs/Jaded-Encoding-Thaumaturgy/repositories
